@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019 Andri Yngvason
+ * Copyright (c) 2019 - 2021 Andri Yngvason
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -18,6 +18,8 @@
 
 #include <stdint.h>
 #include <unistd.h>
+#include <pixman.h>
+#include <stdbool.h>
 
 struct rfb_pixel_format;
 
@@ -29,3 +31,13 @@ void pixel32_to_cpixel(uint8_t* restrict dst,
 
 int rfb_pixfmt_from_fourcc(struct rfb_pixel_format *dst, uint32_t src);
 uint32_t rfb_pixfmt_to_fourcc(const struct rfb_pixel_format* fmt);
+
+int pixel_size_from_fourcc(uint32_t fourcc);
+
+bool fourcc_to_pixman_fmt(pixman_format_code_t* dst, uint32_t src);
+
+bool extract_alpha_mask(uint8_t* dst, const void* src, uint32_t format,
+		size_t len);
+
+const char* drm_format_to_string(uint32_t fmt);
+const char* rfb_pixfmt_to_string(const struct rfb_pixel_format* fmt);
